## 简介
Easy implementation and abstraction for train and deploy model on ray cluster

## 资源清单
1. docker image  
   docker.4pd.io/ray_tensorflow2:pipe-105-commit-aa96d082
2. 安装文档  
./doc
3. 安装
pip install raypip